---
title: MySqlErrorCode
---

# MySqlErrorCode enumeration

MySQL Server error codes. Taken from [Server Error Codes and Messages](https://dev.mysql.com/doc/refman/5.7/en/error-messages-server.html).

```csharp
public enum MySqlErrorCode
```

## Values

| name | value | description |
| --- | --- | --- |
| BulkCopyFailed | `-2` | Not all rows from the source supplied to [`MySqlBulkCopy`](../MySqlBulkCopyType/) were copied to [`DestinationTableName`](../MySqlBulkCopy/DestinationTableName/). |
| CommandTimeoutExpired | `-1` | The timeout period specified by [`CommandTimeout`](../MySqlCommand/CommandTimeout/) elapsed before the operation completed. |
| None | `0` |  |
| HashCheck | `1000` | ER_HASHCHK |
| ISAMCheck | `1001` | ER_NISAMCHK |
| No | `1002` | ER_NO |
| Yes | `1003` | ER_YES |
| CannotCreateFile | `1004` | ER_CANT_CREATE_FILE |
| CannotCreateTable | `1005` | ER_CANT_CREATE_TABLE |
| CannotCreateDatabase | `1006` | ER_CANT_CREATE_DB |
| DatabaseCreateExists | `1007` | ER_DB_CREATE_EXISTS |
| DatabaseDropExists | `1008` | ER_DB_DROP_EXISTS |
| DatabaseDropDelete | `1009` | ER_DB_DROP_DELETE |
| DatabaseDropRemoveDir | `1010` | ER_DB_DROP_RMDIR |
| CannotDeleteFile | `1011` | ER_CANT_DELETE_FILE |
| CannotFindSystemRecord | `1012` | ER_CANT_FIND_SYSTEM_REC |
| CannotGetStatus | `1013` | ER_CANT_GET_STAT |
| CannotGetWorkingDirectory | `1014` | ER_CANT_GET_WD |
| CannotLock | `1015` | ER_CANT_LOCK |
| CannotOpenFile | `1016` | ER_CANT_OPEN_FILE |
| FileNotFound | `1017` | ER_FILE_NOT_FOUND |
| CannotReadDirectory | `1018` | ER_CANT_READ_DIR |
| CannotSetWorkingDirectory | `1019` | ER_CANT_SET_WD |
| CheckRead | `1020` | ER_CHECKREAD |
| DiskFull | `1021` | ER_DISK_FULL |
| DuplicateKey | `1022` | ER_DUP_KEY |
| ErrorOnClose | `1023` | ER_ERROR_ON_CLOSE |
| ErrorOnRead | `1024` | ER_ERROR_ON_READ |
| ErrorOnRename | `1025` | ER_ERROR_ON_RENAME |
| ErrorOnWrite | `1026` | ER_ERROR_ON_WRITE |
| FileUsed | `1027` | ER_FILE_USED |
| FileSortAborted | `1028` | ER_FILSORT_ABORT |
| FormNotFound | `1029` | ER_FORM_NOT_FOUND |
| GetErrorNumber | `1030` | ER_GET_ERRNO |
| IllegalHA | `1031` | ER_ILLEGAL_HA |
| KeyNotFound | `1032` | ER_KEY_NOT_FOUND |
| NotFormFile | `1033` | ER_NOT_FORM_FILE |
| NotKeyFile | `1034` | ER_NOT_KEYFILE |
| OldKeyFile | `1035` | ER_OLD_KEYFILE |
| OpenAsReadOnly | `1036` | ER_OPEN_AS_READONLY |
| OutOfMemory | `1037` | ER_OUTOFMEMORY |
| OutOfSortMemory | `1038` | ER_OUT_OF_SORTMEMORY |
| UnexepectedEOF | `1039` | ER_UNEXPECTED_EOF |
| ConnectionCountError | `1040` | ER_CON_COUNT_ERROR |
| OutOfResources | `1041` | ER_OUT_OF_RESOURCES |
| UnableToConnectToHost | `1042` | ER_BAD_HOST_ERROR |
| HandshakeError | `1043` | ER_HANDSHAKE_ERROR |
| DatabaseAccessDenied | `1044` | ER_DBACCESS_DENIED_ERROR |
| AccessDenied | `1045` | ER_ACCESS_DENIED_ERROR |
| NoDatabaseSelected | `1046` | ER_NO_DB_ERROR |
| UnknownCommand | `1047` | ER_UNKNOWN_COM_ERROR |
| ColumnCannotBeNull | `1048` | ER_BAD_NULL_ERROR |
| UnknownDatabase | `1049` | ER_BAD_DB_ERROR |
| TableExists | `1050` | ER_TABLE_EXISTS_ERROR |
| BadTable | `1051` | ER_BAD_TABLE_ERROR |
| NonUnique | `1052` | ER_NON_UNIQ_ERROR |
| ServerShutdown | `1053` | ER_SERVER_SHUTDOWN |
| BadFieldError | `1054` | ER_BAD_FIELD_ERROR |
| WrongFieldWithGroup | `1055` | ER_WRONG_FIELD_WITH_GROUP |
| WrongGroupField | `1056` | ER_WRONG_GROUP_FIELD |
| WrongSumSelected | `1057` | ER_WRONG_SUM_SELECT |
| WrongValueCount | `1058` | ER_WRONG_VALUE_COUNT |
| TooLongIdentifier | `1059` | ER_TOO_LONG_IDENT |
| DuplicateFieldName | `1060` | ER_DUP_FIELDNAME |
| DuplicateKeyName | `1061` | ER_DUP_KEYNAME |
| DuplicateKeyEntry | `1062` | ER_DUP_ENTRY |
| WrongFieldSpecifier | `1063` | ER_WRONG_FIELD_SPEC |
| ParseError | `1064` | You have an error in your SQL syntax (ER_PARSE_ERROR). |
| EmptyQuery | `1065` | ER_EMPTY_QUERY |
| NonUniqueTable | `1066` | ER_NONUNIQ_TABLE |
| InvalidDefault | `1067` | ER_INVALID_DEFAULT |
| MultiplePrimaryKey | `1068` | ER_MULTIPLE_PRI_KEY |
| TooManyKeys | `1069` | ER_TOO_MANY_KEYS |
| TooManyKeysParts | `1070` | ER_TOO_MANY_KEY_PARTS |
| TooLongKey | `1071` | ER_TOO_LONG_KEY |
| KeyColumnDoesNotExist | `1072` | ER_KEY_COLUMN_DOES_NOT_EXITS |
| BlobUsedAsKey | `1073` | ER_BLOB_USED_AS_KEY |
| TooBigFieldLength | `1074` | ER_TOO_BIG_FIELDLENGTH |
| WrongAutoKey | `1075` | ER_WRONG_AUTO_KEY |
| Ready | `1076` | ER_READY |
| NormalShutdown | `1077` | ER_NORMAL_SHUTDOWN |
| GotSignal | `1078` | ER_GOT_SIGNAL |
| ShutdownComplete | `1079` | ER_SHUTDOWN_COMPLETE |
| ForcingClose | `1080` | ER_FORCING_CLOSE |
| IPSocketError | `1081` | ER_IPSOCK_ERROR |
| NoSuchIndex | `1082` | ER_NO_SUCH_INDEX |
| WrongFieldTerminators | `1083` | ER_WRONG_FIELD_TERMINATORS |
| BlobsAndNoTerminated | `1084` | ER_BLOBS_AND_NO_TERMINATED |
| TextFileNotReadable | `1085` | ER_TEXTFILE_NOT_READABLE |
| FileExists | `1086` | ER_FILE_EXISTS_ERROR |
| LoadInfo | `1087` | ER_LOAD_INFO |
| AlterInfo | `1088` | ER_ALTER_INFO |
| WrongSubKey | `1089` | ER_WRONG_SUB_KEY |
| CannotRemoveAllFields | `1090` | ER_CANT_REMOVE_ALL_FIELDS |
| CannotDropFieldOrKey | `1091` | ER_CANT_DROP_FIELD_OR_KEY |
| InsertInfo | `1092` | ER_INSERT_INFO |
| UpdateTableUsed | `1093` | ER_UPDATE_TABLE_USED |
| NoSuchThread | `1094` | ER_NO_SUCH_THREAD |
| KillDenied | `1095` | ER_KILL_DENIED_ERROR |
| NoTablesUsed | `1096` | ER_NO_TABLES_USED |
| TooBigSet | `1097` | ER_TOO_BIG_SET |
| NoUniqueLogFile | `1098` | ER_NO_UNIQUE_LOGFILE |
| TableNotLockedForWrite | `1099` | ER_TABLE_NOT_LOCKED_FOR_WRITE |
| TableNotLocked | `1100` | ER_TABLE_NOT_LOCKED |
| BlobCannotHaveDefault | `1101` | ER_BLOB_CANT_HAVE_DEFAULT |
| WrongDatabaseName | `1102` | ER_WRONG_DB_NAME |
| WrongTableName | `1103` | ER_WRONG_TABLE_NAME |
| TooBigSelect | `1104` | ER_TOO_BIG_SELECT |
| UnknownError | `1105` | ER_UNKNOWN_ERROR |
| UnknownProcedure | `1106` | ER_UNKNOWN_PROCEDURE |
| WrongParameterCountToProcedure | `1107` | ER_WRONG_PARAMCOUNT_TO_PROCEDURE |
| WrongParametersToProcedure | `1108` | ER_WRONG_PARAMETERS_TO_PROCEDURE |
| UnknownTable | `1109` | ER_UNKNOWN_TABLE |
| FieldSpecifiedTwice | `1110` | ER_FIELD_SPECIFIED_TWICE |
| InvalidGroupFunctionUse | `1111` | ER_INVALID_GROUP_FUNC_USE |
| UnsupportedExtenstion | `1112` | ER_UNSUPPORTED_EXTENSION |
| TableMustHaveColumns | `1113` | ER_TABLE_MUST_HAVE_COLUMNS |
| RecordFileFull | `1114` | ER_RECORD_FILE_FULL |
| UnknownCharacterSet | `1115` | ER_UNKNOWN_CHARACTER_SET |
| TooManyTables | `1116` | ER_TOO_MANY_TABLES |
| TooManyFields | `1117` | ER_TOO_MANY_FIELDS |
| TooBigRowSize | `1118` | ER_TOO_BIG_ROWSIZE |
| StackOverrun | `1119` | ER_STACK_OVERRUN |
| WrongOuterJoin | `1120` | ER_WRONG_OUTER_JOIN |
| NullColumnInIndex | `1121` | ER_NULL_COLUMN_IN_INDEX |
| CannotFindUDF | `1122` | ER_CANT_FIND_UDF |
| CannotInitializeUDF | `1123` | ER_CANT_INITIALIZE_UDF |
| UDFNoPaths | `1124` | ER_UDF_NO_PATHS |
| UDFExists | `1125` | ER_UDF_EXISTS |
| CannotOpenLibrary | `1126` | ER_CANT_OPEN_LIBRARY |
| CannotFindDLEntry | `1127` | ER_CANT_FIND_DL_ENTRY |
| FunctionNotDefined | `1128` | ER_FUNCTION_NOT_DEFINED |
| HostIsBlocked | `1129` | ER_HOST_IS_BLOCKED |
| HostNotPrivileged | `1130` | ER_HOST_NOT_PRIVILEGED |
| AnonymousUser | `1131` | ER_PASSWORD_ANONYMOUS_USER |
| PasswordNotAllowed | `1132` | ER_PASSWORD_NOT_ALLOWED |
| PasswordNoMatch | `1133` | ER_PASSWORD_NO_MATCH |
| UpdateInfo | `1134` | ER_UPDATE_INFO |
| CannotCreateThread | `1135` | ER_CANT_CREATE_THREAD |
| WrongValueCountOnRow | `1136` | ER_WRONG_VALUE_COUNT_ON_ROW |
| CannotReopenTable | `1137` | ER_CANT_REOPEN_TABLE |
| InvalidUseOfNull | `1138` | ER_INVALID_USE_OF_NULL |
| RegExpError | `1139` | ER_REGEXP_ERROR |
| MixOfGroupFunctionAndFields | `1140` | ER_MIX_OF_GROUP_FUNC_AND_FIELDS |
| NonExistingGrant | `1141` | ER_NONEXISTING_GRANT |
| TableAccessDenied | `1142` | ER_TABLEACCESS_DENIED_ERROR |
| ColumnAccessDenied | `1143` | ER_COLUMNACCESS_DENIED_ERROR |
| IllegalGrantForTable | `1144` | ER_ILLEGAL_GRANT_FOR_TABLE |
| GrantWrongHostOrUser | `1145` | ER_GRANT_WRONG_HOST_OR_USER |
| NoSuchTable | `1146` | ER_NO_SUCH_TABLE |
| NonExistingTableGrant | `1147` | ER_NONEXISTING_TABLE_GRANT |
| NotAllowedCommand | `1148` | ER_NOT_ALLOWED_COMMAND |
| SyntaxError | `1149` | ER_SYNTAX_ERROR |
| DelayedCannotChangeLock | `1150` | ER_UNUSED1 |
| TooManyDelayedThreads | `1151` | ER_UNUSED2 |
| AbortingConnection | `1152` | ER_ABORTING_CONNECTION |
| PacketTooLarge | `1153` | ER_NET_PACKET_TOO_LARGE |
| NetReadErrorFromPipe | `1154` | ER_NET_READ_ERROR_FROM_PIPE |
| NetFCntlError | `1155` | ER_NET_FCNTL_ERROR |
| NetPacketsOutOfOrder | `1156` | ER_NET_PACKETS_OUT_OF_ORDER |
| NetUncompressError | `1157` | ER_NET_UNCOMPRESS_ERROR |
| NetReadError | `1158` | ER_NET_READ_ERROR |
| NetReadInterrupted | `1159` | ER_NET_READ_INTERRUPTED |
| NetErrorOnWrite | `1160` | ER_NET_ERROR_ON_WRITE |
| NetWriteInterrupted | `1161` | ER_NET_WRITE_INTERRUPTED |
| TooLongString | `1162` | ER_TOO_LONG_STRING |
| TableCannotHandleBlob | `1163` | ER_TABLE_CANT_HANDLE_BLOB |
| TableCannotHandleAutoIncrement | `1164` | ER_TABLE_CANT_HANDLE_AUTO_INCREMENT |
| DelayedInsertTableLocked | `1165` | ER_UNUSED3 |
| WrongColumnName | `1166` | ER_WRONG_COLUMN_NAME |
| WrongKeyColumn | `1167` | ER_WRONG_KEY_COLUMN |
| WrongMergeTable | `1168` | ER_WRONG_MRG_TABLE |
| DuplicateUnique | `1169` | ER_DUP_UNIQUE |
| BlobKeyWithoutLength | `1170` | ER_BLOB_KEY_WITHOUT_LENGTH |
| PrimaryCannotHaveNull | `1171` | ER_PRIMARY_CANT_HAVE_NULL |
| TooManyRows | `1172` | ER_TOO_MANY_ROWS |
| RequiresPrimaryKey | `1173` | ER_REQUIRES_PRIMARY_KEY |
| NoRAIDCompiled | `1174` | ER_NO_RAID_COMPILED |
| UpdateWithoutKeysInSafeMode | `1175` | ER_UPDATE_WITHOUT_KEY_IN_SAFE_MODE |
| KeyDoesNotExist | `1176` | ER_KEY_DOES_NOT_EXITS |
| CheckNoSuchTable | `1177` | ER_CHECK_NO_SUCH_TABLE |
| CheckNotImplemented | `1178` | ER_CHECK_NOT_IMPLEMENTED |
| CannotDoThisDuringATransaction | `1179` | ER_CANT_DO_THIS_DURING_AN_TRANSACTION |
| ErrorDuringCommit | `1180` | ER_ERROR_DURING_COMMIT |
| ErrorDuringRollback | `1181` | ER_ERROR_DURING_ROLLBACK |
| ErrorDuringFlushLogs | `1182` | ER_ERROR_DURING_FLUSH_LOGS |
| ErrorDuringCheckpoint | `1183` | ER_ERROR_DURING_CHECKPOINT |
| NewAbortingConnection | `1184` | ER_NEW_ABORTING_CONNECTION |
| DumpNotImplemented | `1185` | ER_DUMP_NOT_IMPLEMENTED |
| FlushMasterBinLogClosed | `1186` | ER_FLUSH_MASTER_BINLOG_CLOSED |
| IndexRebuild | `1187` | ER_INDEX_REBUILD |
| MasterError | `1188` | ER_MASTER |
| MasterNetRead | `1189` | ER_MASTER_NET_READ |
| MasterNetWrite | `1190` | ER_MASTER_NET_WRITE |
| FullTextMatchingKeyNotFound | `1191` | ER_FT_MATCHING_KEY_NOT_FOUND |
| LockOrActiveTransaction | `1192` | ER_LOCK_OR_ACTIVE_TRANSACTION |
| UnknownSystemVariable | `1193` | ER_UNKNOWN_SYSTEM_VARIABLE |
| CrashedOnUsage | `1194` | ER_CRASHED_ON_USAGE |
| CrashedOnRepair | `1195` | ER_CRASHED_ON_REPAIR |
| WarningNotCompleteRollback | `1196` | ER_WARNING_NOT_COMPLETE_ROLLBACK |
| TransactionCacheFull | `1197` | ER_TRANS_CACHE_FULL |
| SlaveMustStop | `1198` | ER_SLAVE_MUST_STOP |
| SlaveNotRunning | `1199` | ER_SLAVE_NOT_RUNNING |
| BadSlave | `1200` | ER_BAD_SLAVE |
| MasterInfo | `1201` | ER_MASTER_INFO |
| SlaveThread | `1202` | ER_SLAVE_THREAD |
| TooManyUserConnections | `1203` | ER_TOO_MANY_USER_CONNECTIONS |
| SetConstantsOnly | `1204` | ER_SET_CONSTANTS_ONLY |
| LockWaitTimeout | `1205` | ER_LOCK_WAIT_TIMEOUT |
| LockTableFull | `1206` | ER_LOCK_TABLE_FULL |
| ReadOnlyTransaction | `1207` | ER_READ_ONLY_TRANSACTION |
| DropDatabaseWithReadLock | `1208` | ER_DROP_DB_WITH_READ_LOCK |
| CreateDatabaseWithReadLock | `1209` | ER_CREATE_DB_WITH_READ_LOCK |
| WrongArguments | `1210` | ER_WRONG_ARGUMENTS |
| NoPermissionToCreateUser | `1211` | ER_NO_PERMISSION_TO_CREATE_USER |
| UnionTablesInDifferentDirectory | `1212` | ER_UNION_TABLES_IN_DIFFERENT_DIR |
| LockDeadlock | `1213` | ER_LOCK_DEADLOCK |
| TableCannotHandleFullText | `1214` | ER_TABLE_CANT_HANDLE_FT |
| CannotAddForeignConstraint | `1215` | ER_CANNOT_ADD_FOREIGN |
| NoReferencedRow | `1216` | ER_NO_REFERENCED_ROW |
| RowIsReferenced | `1217` | ER_ROW_IS_REFERENCED |
| ConnectToMaster | `1218` | ER_CONNECT_TO_MASTER |
| QueryOnMaster | `1219` | ER_QUERY_ON_MASTER |
| ErrorWhenExecutingCommand | `1220` | ER_ERROR_WHEN_EXECUTING_COMMAND |
| WrongUsage | `1221` | ER_WRONG_USAGE |
| WrongNumberOfColumnsInSelect | `1222` | ER_WRONG_NUMBER_OF_COLUMNS_IN_SELECT |
| CannotUpdateWithReadLock | `1223` | ER_CANT_UPDATE_WITH_READLOCK |
| MixingNotAllowed | `1224` | ER_MIXING_NOT_ALLOWED |
| DuplicateArgument | `1225` | ER_DUP_ARGUMENT |
| UserLimitReached | `1226` | ER_USER_LIMIT_REACHED |
| SpecifiedAccessDeniedError | `1227` | ER_SPECIFIC_ACCESS_DENIED_ERROR |
| LocalVariableError | `1228` | ER_LOCAL_VARIABLE |
| GlobalVariableError | `1229` | ER_GLOBAL_VARIABLE |
| NotDefaultError | `1230` | ER_NO_DEFAULT |
| WrongValueForVariable | `1231` | ER_WRONG_VALUE_FOR_VAR |
| WrongTypeForVariable | `1232` | ER_WRONG_TYPE_FOR_VAR |
| VariableCannotBeRead | `1233` | ER_VAR_CANT_BE_READ |
| CannotUseOptionHere | `1234` | ER_CANT_USE_OPTION_HERE |
| NotSupportedYet | `1235` | ER_NOT_SUPPORTED_YET |
| MasterFatalErrorReadingBinLog | `1236` | ER_MASTER_FATAL_ERROR_READING_BINLOG |
| SlaveIgnoredTable | `1237` | ER_SLAVE_IGNORED_TABLE |
| IncorrectGlobalLocalVariable | `1238` | ER_INCORRECT_GLOBAL_LOCAL_VAR |
| WrongForeignKeyDefinition | `1239` | ER_WRONG_FK_DEF |
| KeyReferenceDoesNotMatchTableReference | `1240` | ER_KEY_REF_DO_NOT_MATCH_TABLE_REF |
| OpearnColumnsError | `1241` | ER_OPERAND_COLUMNS |
| SubQueryNoOneRow | `1242` | ER_SUBQUERY_NO_1_ROW |
| UnknownStatementHandler | `1243` | ER_UNKNOWN_STMT_HANDLER |
| CorruptHelpDatabase | `1244` | ER_CORRUPT_HELP_DB |
| CyclicReference | `1245` | ER_CYCLIC_REFERENCE |
| AutoConvert | `1246` | ER_AUTO_CONVERT |
| IllegalReference | `1247` | ER_ILLEGAL_REFERENCE |
| DerivedMustHaveAlias | `1248` | ER_DERIVED_MUST_HAVE_ALIAS |
| SelectReduced | `1249` | ER_SELECT_REDUCED |
| TableNameNotAllowedHere | `1250` | ER_TABLENAME_NOT_ALLOWED_HERE |
| NotSupportedAuthMode | `1251` | ER_NOT_SUPPORTED_AUTH_MODE |
| SpatialCannotHaveNull | `1252` | ER_SPATIAL_CANT_HAVE_NULL |
| CollationCharsetMismatch | `1253` | ER_COLLATION_CHARSET_MISMATCH |
| SlaveWasRunning | `1254` | ER_SLAVE_WAS_RUNNING |
| SlaveWasNotRunning | `1255` | ER_SLAVE_WAS_NOT_RUNNING |
| TooBigForUncompress | `1256` | ER_TOO_BIG_FOR_UNCOMPRESS |
| ZipLibMemoryError | `1257` | ER_ZLIB_Z_MEM_ERROR |
| ZipLibBufferError | `1258` | ER_ZLIB_Z_BUF_ERROR |
| ZipLibDataError | `1259` | ER_ZLIB_Z_DATA_ERROR |
| CutValueGroupConcat | `1260` | ER_CUT_VALUE_GROUP_CONCAT |
| WarningTooFewRecords | `1261` | ER_WARN_TOO_FEW_RECORDS |
| WarningTooManyRecords | `1262` | ER_WARN_TOO_MANY_RECORDS |
| WarningNullToNotNull | `1263` | ER_WARN_NULL_TO_NOTNULL |
| WarningDataOutOfRange | `1264` | ER_WARN_DATA_OUT_OF_RANGE |
| WaningDataTruncated | `1265` | WARN_DATA_TRUNCATED |
| WaningUsingOtherHandler | `1266` | ER_WARN_USING_OTHER_HANDLER |
| CannotAggregateTwoCollations | `1267` | ER_CANT_AGGREGATE_2COLLATIONS |
| DropUserError | `1268` | ER_DROP_USER |
| RevokeGrantsError | `1269` | ER_REVOKE_GRANTS |
| CannotAggregateThreeCollations | `1270` | ER_CANT_AGGREGATE_3COLLATIONS |
| CannotAggregateNCollations | `1271` | ER_CANT_AGGREGATE_NCOLLATIONS |
| VariableIsNotStructure | `1272` | ER_VARIABLE_IS_NOT_STRUCT |
| UnknownCollation | `1273` | ER_UNKNOWN_COLLATION |
| SlaveIgnoreSSLParameters | `1274` | ER_SLAVE_IGNORED_SSL_PARAMS |
| ServerIsInSecureAuthMode | `1275` | ER_SERVER_IS_IN_SECURE_AUTH_MODE |
| WaningFieldResolved | `1276` | ER_WARN_FIELD_RESOLVED |
| BadSlaveUntilCondition | `1277` | ER_BAD_SLAVE_UNTIL_COND |
| MissingSkipSlave | `1278` | ER_MISSING_SKIP_SLAVE |
| ErrorUntilConditionIgnored | `1279` | ER_UNTIL_COND_IGNORED |
| WrongNameForIndex | `1280` | ER_WRONG_NAME_FOR_INDEX |
| WrongNameForCatalog | `1281` | ER_WRONG_NAME_FOR_CATALOG |
| WarningQueryCacheResize | `1282` | ER_WARN_QC_RESIZE |
| BadFullTextColumn | `1283` | ER_BAD_FT_COLUMN |
| UnknownKeyCache | `1284` | ER_UNKNOWN_KEY_CACHE |
| WarningHostnameWillNotWork | `1285` | ER_WARN_HOSTNAME_WONT_WORK |
| UnknownStorageEngine | `1286` | ER_UNKNOWN_STORAGE_ENGINE |
| WaningDeprecatedSyntax | `1287` | ER_WARN_DEPRECATED_SYNTAX |
| NonUpdateableTable | `1288` | ER_NON_UPDATABLE_TABLE |
| FeatureDisabled | `1289` | ER_FEATURE_DISABLED |
| OptionPreventsStatement | `1290` | ER_OPTION_PREVENTS_STATEMENT |
| DuplicatedValueInType | `1291` | ER_DUPLICATED_VALUE_IN_TYPE |
| TruncatedWrongValue | `1292` | ER_TRUNCATED_WRONG_VALUE |
| TooMuchAutoTimestampColumns | `1293` | ER_TOO_MUCH_AUTO_TIMESTAMP_COLS |
| InvalidOnUpdate | `1294` | ER_INVALID_ON_UPDATE |
| UnsupportedPreparedStatement | `1295` | ER_UNSUPPORTED_PS |
| GetErroMessage | `1296` | ER_GET_ERRMSG |
| GetTemporaryErrorMessage | `1297` | ER_GET_TEMPORARY_ERRMSG |
| UnknownTimeZone | `1298` | ER_UNKNOWN_TIME_ZONE |
| WarningInvalidTimestamp | `1299` | ER_WARN_INVALID_TIMESTAMP |
| InvalidCharacterString | `1300` | ER_INVALID_CHARACTER_STRING |
| WarningAllowedPacketOverflowed | `1301` | ER_WARN_ALLOWED_PACKET_OVERFLOWED |
| ConflictingDeclarations | `1302` | ER_CONFLICTING_DECLARATIONS |
| StoredProcedureNoRecursiveCreate | `1303` | ER_SP_NO_RECURSIVE_CREATE |
| StoredProcedureAlreadyExists | `1304` | ER_SP_ALREADY_EXISTS |
| StoredProcedureDoesNotExist | `1305` | ER_SP_DOES_NOT_EXIST |
| StoredProcedureDropFailed | `1306` | ER_SP_DROP_FAILED |
| StoredProcedureStoreFailed | `1307` | ER_SP_STORE_FAILED |
| StoredProcedureLiLabelMismatch | `1308` | ER_SP_LILABEL_MISMATCH |
| StoredProcedureLabelRedefine | `1309` | ER_SP_LABEL_REDEFINE |
| StoredProcedureLabelMismatch | `1310` | ER_SP_LABEL_MISMATCH |
| StoredProcedureUninitializedVariable | `1311` | ER_SP_UNINIT_VAR |
| StoredProcedureBadSelect | `1312` | ER_SP_BADSELECT |
| StoredProcedureBadReturn | `1313` | ER_SP_BADRETURN |
| StoredProcedureBadStatement | `1314` | ER_SP_BADSTATEMENT |
| UpdateLogDeprecatedIgnored | `1315` | ER_UPDATE_LOG_DEPRECATED_IGNORED |
| UpdateLogDeprecatedTranslated | `1316` | ER_UPDATE_LOG_DEPRECATED_TRANSLATED |
| QueryInterrupted | `1317` | Query execution was interrupted (ER_QUERY_INTERRUPTED). |
| StoredProcedureNumberOfArguments | `1318` | ER_SP_WRONG_NO_OF_ARGS |
| StoredProcedureConditionMismatch | `1319` | ER_SP_COND_MISMATCH |
| StoredProcedureNoReturn | `1320` | ER_SP_NORETURN |
| StoredProcedureNoReturnEnd | `1321` | ER_SP_NORETURNEND |
| StoredProcedureBadCursorQuery | `1322` | ER_SP_BAD_CURSOR_QUERY |
| StoredProcedureBadCursorSelect | `1323` | ER_SP_BAD_CURSOR_SELECT |
| StoredProcedureCursorMismatch | `1324` | ER_SP_CURSOR_MISMATCH |
| StoredProcedureAlreadyOpen | `1325` | ER_SP_CURSOR_ALREADY_OPEN |
| StoredProcedureCursorNotOpen | `1326` | ER_SP_CURSOR_NOT_OPEN |
| StoredProcedureUndeclaredVariabel | `1327` | ER_SP_UNDECLARED_VAR |
| StoredProcedureWrongNumberOfFetchArguments | `1328` | ER_SP_WRONG_NO_OF_FETCH_ARGS |
| StoredProcedureFetchNoData | `1329` | ER_SP_FETCH_NO_DATA |
| StoredProcedureDuplicateParameter | `1330` | ER_SP_DUP_PARAM |
| StoredProcedureDuplicateVariable | `1331` | ER_SP_DUP_VAR |
| StoredProcedureDuplicateCondition | `1332` | ER_SP_DUP_COND |
| StoredProcedureDuplicateCursor | `1333` | ER_SP_DUP_CURS |
| StoredProcedureCannotAlter | `1334` | ER_SP_CANT_ALTER |
| StoredProcedureSubSelectNYI | `1335` | ER_SP_SUBSELECT_NYI |
| StatementNotAllowedInStoredFunctionOrTrigger | `1336` | ER_STMT_NOT_ALLOWED_IN_SF_OR_TRG |
| StoredProcedureVariableConditionAfterCursorHandler | `1337` | ER_SP_VARCOND_AFTER_CURSHNDLR |
| StoredProcedureCursorAfterHandler | `1338` | ER_SP_CURSOR_AFTER_HANDLER |
| StoredProcedureCaseNotFound | `1339` | ER_SP_CASE_NOT_FOUND |
| FileParserTooBigFile | `1340` | ER_FPARSER_TOO_BIG_FILE |
| FileParserBadHeader | `1341` | ER_FPARSER_BAD_HEADER |
| FileParserEOFInComment | `1342` | ER_FPARSER_EOF_IN_COMMENT |
| FileParserErrorInParameter | `1343` | ER_FPARSER_ERROR_IN_PARAMETER |
| FileParserEOFInUnknownParameter | `1344` | ER_FPARSER_EOF_IN_UNKNOWN_PARAMETER |
| ViewNoExplain | `1345` | ER_VIEW_NO_EXPLAIN |
| FrmUnknownType | `1346` | ER_FRM_UNKNOWN_TYPE |
| WrongObject | `1347` | ER_WRONG_OBJECT |
| NonUpdateableColumn | `1348` | ER_NONUPDATEABLE_COLUMN |
| ViewSelectDerived | `1349` | ER_VIEW_SELECT_DERIVED |
| ViewSelectClause | `1350` | ER_VIEW_SELECT_CLAUSE |
| ViewSelectVariable | `1351` | ER_VIEW_SELECT_VARIABLE |
| ViewSelectTempTable | `1352` | ER_VIEW_SELECT_TMPTABLE |
| ViewWrongList | `1353` | ER_VIEW_WRONG_LIST |
| WarningViewMerge | `1354` | ER_WARN_VIEW_MERGE |
| WarningViewWithoutKey | `1355` | ER_WARN_VIEW_WITHOUT_KEY |
| ViewInvalid | `1356` | ER_VIEW_INVALID |
| StoredProcedureNoDropStoredProcedure | `1357` | ER_SP_NO_DROP_SP |
| StoredProcedureGotoInHandler | `1358` | ER_SP_GOTO_IN_HNDLR |
| TriggerAlreadyExists | `1359` | ER_TRG_ALREADY_EXISTS |
| TriggerDoesNotExist | `1360` | ER_TRG_DOES_NOT_EXIST |
| TriggerOnViewOrTempTable | `1361` | ER_TRG_ON_VIEW_OR_TEMP_TABLE |
| TriggerCannotChangeRow | `1362` | ER_TRG_CANT_CHANGE_ROW |
| TriggerNoSuchRowInTrigger | `1363` | ER_TRG_NO_SUCH_ROW_IN_TRG |
| NoDefaultForField | `1364` | ER_NO_DEFAULT_FOR_FIELD |
| DivisionByZero | `1365` | ER_DIVISION_BY_ZERO |
| TruncatedWrongValueForField | `1366` | ER_TRUNCATED_WRONG_VALUE_FOR_FIELD |
| IllegalValueForType | `1367` | ER_ILLEGAL_VALUE_FOR_TYPE |
| ViewNonUpdatableCheck | `1368` | ER_VIEW_NONUPD_CHECK |
| ViewCheckFailed | `1369` | ER_VIEW_CHECK_FAILED |
| PrecedureAccessDenied | `1370` | ER_PROCACCESS_DENIED_ERROR |
| RelayLogFail | `1371` | ER_RELAY_LOG_FAIL |
| PasswordLength | `1372` | ER_PASSWD_LENGTH |
| UnknownTargetBinLog | `1373` | ER_UNKNOWN_TARGET_BINLOG |
| IOErrorLogIndexRead | `1374` | ER_IO_ERR_LOG_INDEX_READ |
| BinLogPurgeProhibited | `1375` | ER_BINLOG_PURGE_PROHIBITED |
| FSeekFail | `1376` | ER_FSEEK_FAIL |
| BinLogPurgeFatalError | `1377` | ER_BINLOG_PURGE_FATAL_ERR |
| LogInUse | `1378` | ER_LOG_IN_USE |
| LogPurgeUnknownError | `1379` | ER_LOG_PURGE_UNKNOWN_ERR |
| RelayLogInit | `1380` | ER_RELAY_LOG_INIT |
| NoBinaryLogging | `1381` | ER_NO_BINARY_LOGGING |
| ReservedSyntax | `1382` | ER_RESERVED_SYNTAX |
| WSAStartupFailed | `1383` | ER_WSAS_FAILED |
| DifferentGroupsProcedure | `1384` | ER_DIFF_GROUPS_PROC |
| NoGroupForProcedure | `1385` | ER_NO_GROUP_FOR_PROC |
| OrderWithProcedure | `1386` | ER_ORDER_WITH_PROC |
| LoggingProhibitsChangingOf | `1387` | ER_LOGGING_PROHIBIT_CHANGING_OF |
| NoFileMapping | `1388` | ER_NO_FILE_MAPPING |
| WrongMagic | `1389` | ER_WRONG_MAGIC |
| PreparedStatementManyParameters | `1390` | ER_PS_MANY_PARAM |
| KeyPartZero | `1391` | ER_KEY_PART_0 |
| ViewChecksum | `1392` | ER_VIEW_CHECKSUM |
| ViewMultiUpdate | `1393` | ER_VIEW_MULTIUPDATE |
| ViewNoInsertFieldList | `1394` | ER_VIEW_NO_INSERT_FIELD_LIST |
| ViewDeleteMergeView | `1395` | ER_VIEW_DELETE_MERGE_VIEW |
| CannotUser | `1396` | ER_CANNOT_USER |
| XAERNotA | `1397` | ER_XAER_NOTA |
| XAERInvalid | `1398` | ER_XAER_INVAL |
| XAERRemoveFail | `1399` | ER_XAER_RMFAIL |
| XAEROutside | `1400` | ER_XAER_OUTSIDE |
| XAERRemoveError | `1401` | ER_XAER_RMERR |
| XARBRollback | `1402` | ER_XA_RBROLLBACK |
| NonExistingProcedureGrant | `1403` | ER_NONEXISTING_PROC_GRANT |
| ProcedureAutoGrantFail | `1404` | ER_PROC_AUTO_GRANT_FAIL |
| ProcedureAutoRevokeFail | `1405` | ER_PROC_AUTO_REVOKE_FAIL |
| DataTooLong | `1406` | ER_DATA_TOO_LONG |
| StoredProcedureSQLState | `1407` | ER_SP_BAD_SQLSTATE |
| StartupError | `1408` | ER_STARTUP |
| LoadFromFixedSizeRowsToVariable | `1409` | ER_LOAD_FROM_FIXED_SIZE_ROWS_TO_VAR |
| CannotCreateUserWithGrant | `1410` | ER_CANT_CREATE_USER_WITH_GRANT |
| WrongValueForType | `1411` | ER_WRONG_VALUE_FOR_TYPE |
| TableDefinitionChanged | `1412` | ER_TABLE_DEF_CHANGED |
| StoredProcedureDuplicateHandler | `1413` | ER_SP_DUP_HANDLER |
| StoredProcedureNotVariableArgument | `1414` | ER_SP_NOT_VAR_ARG |
| StoredProcedureNoReturnSet | `1415` | ER_SP_NO_RETSET |
| CannotCreateGeometryObject | `1416` | ER_CANT_CREATE_GEOMETRY_OBJECT |
| FailedRoutineBreaksBinLog | `1417` | ER_FAILED_ROUTINE_BREAK_BINLOG |
| BinLogUnsafeRoutine | `1418` | ER_BINLOG_UNSAFE_ROUTINE |
| BinLogCreateRoutineNeedSuper | `1419` | ER_BINLOG_CREATE_ROUTINE_NEED_SUPER |
| ExecuteStatementWithOpenCursor | `1420` | ER_EXEC_STMT_WITH_OPEN_CURSOR |
| StatementHasNoOpenCursor | `1421` | ER_STMT_HAS_NO_OPEN_CURSOR |
| CommitNotAllowedIfStoredFunctionOrTrigger | `1422` | ER_COMMIT_NOT_ALLOWED_IN_SF_OR_TRG |
| NoDefaultForViewField | `1423` | ER_NO_DEFAULT_FOR_VIEW_FIELD |
| StoredProcedureNoRecursion | `1424` | ER_SP_NO_RECURSION |
| TooBigScale | `1425` | ER_TOO_BIG_SCALE |
| TooBigPrecision | `1426` | ER_TOO_BIG_PRECISION |
| MBiggerThanD | `1427` | ER_M_BIGGER_THAN_D |
| WrongLockOfSystemTable | `1428` | ER_WRONG_LOCK_OF_SYSTEM_TABLE |
| ConnectToForeignDataSource | `1429` | ER_CONNECT_TO_FOREIGN_DATA_SOURCE |
| QueryOnForeignDataSource | `1430` | ER_QUERY_ON_FOREIGN_DATA_SOURCE |
| ForeignDataSourceDoesNotExist | `1431` | ER_FOREIGN_DATA_SOURCE_DOESNT_EXIST |
| ForeignDataStringInvalidCannotCreate | `1432` | ER_FOREIGN_DATA_STRING_INVALID_CANT_CREATE |
| ForeignDataStringInvalid | `1433` | ER_FOREIGN_DATA_STRING_INVALID |
| CannotCreateFederatedTable | `1434` | ER_CANT_CREATE_FEDERATED_TABLE |
| TriggerInWrongSchema | `1435` | ER_TRG_IN_WRONG_SCHEMA |
| StackOverrunNeedMore | `1436` | ER_STACK_OVERRUN_NEED_MORE |
| TooLongBody | `1437` | ER_TOO_LONG_BODY |
| WarningCannotDropDefaultKeyCache | `1438` | ER_WARN_CANT_DROP_DEFAULT_KEYCACHE |
| TooBigDisplayWidth | `1439` | ER_TOO_BIG_DISPLAYWIDTH |
| XAERDuplicateID | `1440` | ER_XAER_DUPID |
| DateTimeFunctionOverflow | `1441` | ER_DATETIME_FUNCTION_OVERFLOW |
| CannotUpdateUsedTableInStoredFunctionOrTrigger | `1442` | ER_CANT_UPDATE_USED_TABLE_IN_SF_OR_TRG |
| ViewPreventUpdate | `1443` | ER_VIEW_PREVENT_UPDATE |
| PreparedStatementNoRecursion | `1444` | ER_PS_NO_RECURSION |
| StoredProcedureCannotSetAutoCommit | `1445` | ER_SP_CANT_SET_AUTOCOMMIT |
| MalformedDefiner | `1446` | ER_MALFORMED_DEFINER |
| ViewFrmNoUser | `1447` | ER_VIEW_FRM_NO_USER |
| ViewOtherUser | `1448` | ER_VIEW_OTHER_USER |
| NoSuchUser | `1449` | ER_NO_SUCH_USER |
| ForbidSchemaChange | `1450` | ER_FORBID_SCHEMA_CHANGE |
| RowIsReferenced2 | `1451` | ER_ROW_IS_REFERENCED_2 |
| NoReferencedRow2 | `1452` | ER_NO_REFERENCED_ROW_2 |
| StoredProcedureBadVariableShadow | `1453` | ER_SP_BAD_VAR_SHADOW |
| TriggerNoDefiner | `1454` | ER_TRG_NO_DEFINER |
| OldFileFormat | `1455` | ER_OLD_FILE_FORMAT |
| StoredProcedureRecursionLimit | `1456` | ER_SP_RECURSION_LIMIT |
| StoredProcedureTableCorrupt | `1457` | ER_SP_PROC_TABLE_CORRUPT |
| StoredProcedureWrongName | `1458` | ER_SP_WRONG_NAME |
| TableNeedsUpgrade | `1459` | ER_TABLE_NEEDS_UPGRADE |
| StoredProcedureNoAggregate | `1460` | ER_SP_NO_AGGREGATE |
| MaxPreparedStatementCountReached | `1461` | ER_MAX_PREPARED_STMT_COUNT_REACHED |
| ViewRecursive | `1462` | ER_VIEW_RECURSIVE |
| NonGroupingFieldUsed | `1463` | ER_NON_GROUPING_FIELD_USED |
| TableCannotHandleSpatialKeys | `1464` | ER_TABLE_CANT_HANDLE_SPKEYS |
| NoTriggersOnSystemSchema | `1465` | ER_NO_TRIGGERS_ON_SYSTEM_SCHEMA |
| RemovedSpaces | `1466` | ER_REMOVED_SPACES |
| AutoIncrementReadFailed | `1467` | ER_AUTOINC_READ_FAILED |
| UserNameError | `1468` | ER_USERNAME |
| HostNameError | `1469` | ER_HOSTNAME |
| WrongStringLength | `1470` | ER_WRONG_STRING_LENGTH |
| NonInsertableTable | `1471` | ER_NON_INSERTABLE_TABLE |
| AdminWrongMergeTable | `1472` | ER_ADMIN_WRONG_MRG_TABLE |
| TooHighLevelOfNestingForSelect | `1473` | ER_TOO_HIGH_LEVEL_OF_NESTING_FOR_SELECT |
| NameBecomesEmpty | `1474` | ER_NAME_BECOMES_EMPTY |
| AmbiguousFieldTerm | `1475` | ER_AMBIGUOUS_FIELD_TERM |
| ForeignServerExists | `1476` | ER_FOREIGN_SERVER_EXISTS |
| ForeignServerDoesNotExist | `1477` | ER_FOREIGN_SERVER_DOESNT_EXIST |
| IllegalHACreateOption | `1478` | ER_ILLEGAL_HA_CREATE_OPTION |
| PartitionRequiresValues | `1479` | ER_PARTITION_REQUIRES_VALUES_ERROR |
| PartitionWrongValues | `1480` | ER_PARTITION_WRONG_VALUES_ERROR |
| PartitionMaxValue | `1481` | ER_PARTITION_MAXVALUE_ERROR |
| PartitionSubPartition | `1482` | ER_PARTITION_SUBPARTITION_ERROR |
| PartitionSubPartMix | `1483` | ER_PARTITION_SUBPART_MIX_ERROR |
| PartitionWrongNoPart | `1484` | ER_PARTITION_WRONG_NO_PART_ERROR |
| PartitionWrongNoSubPart | `1485` | ER_PARTITION_WRONG_NO_SUBPART_ERROR |
| WrongExpressionInParitionFunction | `1486` | ER_WRONG_EXPR_IN_PARTITION_FUNC_ERROR |
| NoConstantExpressionInRangeOrListError | `1487` | ER_NO_CONST_EXPR_IN_RANGE_OR_LIST_ERROR |
| FieldNotFoundPartitionErrror | `1488` | ER_FIELD_NOT_FOUND_PART_ERROR |
| ListOfFieldsOnlyInHash | `1489` | ER_LIST_OF_FIELDS_ONLY_IN_HASH_ERROR |
| InconsistentPartitionInfo | `1490` | ER_INCONSISTENT_PARTITION_INFO_ERROR |
| PartitionFunctionNotAllowed | `1491` | ER_PARTITION_FUNC_NOT_ALLOWED_ERROR |
| PartitionsMustBeDefined | `1492` | ER_PARTITIONS_MUST_BE_DEFINED_ERROR |
| RangeNotIncreasing | `1493` | ER_RANGE_NOT_INCREASING_ERROR |
| InconsistentTypeOfFunctions | `1494` | ER_INCONSISTENT_TYPE_OF_FUNCTIONS_ERROR |
| MultipleDefinitionsConstantInListPartition | `1495` | ER_MULTIPLE_DEF_CONST_IN_LIST_PART_ERROR |
| PartitionEntryError | `1496` | ER_PARTITION_ENTRY_ERROR |
| MixHandlerError | `1497` | ER_MIX_HANDLER_ERROR |
| PartitionNotDefined | `1498` | ER_PARTITION_NOT_DEFINED_ERROR |
| TooManyPartitions | `1499` | ER_TOO_MANY_PARTITIONS_ERROR |
| SubPartitionError | `1500` | ER_SUBPARTITION_ERROR |
| CannotCreateHandlerFile | `1501` | ER_CANT_CREATE_HANDLER_FILE |
| BlobFieldInPartitionFunction | `1502` | ER_BLOB_FIELD_IN_PART_FUNC_ERROR |
| UniqueKeyNeedAllFieldsInPartitioningFunction | `1503` | ER_UNIQUE_KEY_NEED_ALL_FIELDS_IN_PF |
| NoPartitions | `1504` | ER_NO_PARTS_ERROR |
| PartitionManagementOnNoPartitioned | `1505` | ER_PARTITION_MGMT_ON_NONPARTITIONED |
| ForeignKeyOnPartitioned | `1506` | ER_FOREIGN_KEY_ON_PARTITIONED |
| DropPartitionNonExistent | `1507` | ER_DROP_PARTITION_NON_EXISTENT |
| DropLastPartition | `1508` | ER_DROP_LAST_PARTITION |
| CoalesceOnlyOnHashPartition | `1509` | ER_COALESCE_ONLY_ON_HASH_PARTITION |
| ReorganizeHashOnlyOnSameNumber | `1510` | ER_REORG_HASH_ONLY_ON_SAME_NO |
| ReorganizeNoParameter | `1511` | ER_REORG_NO_PARAM_ERROR |
| OnlyOnRangeListPartition | `1512` | ER_ONLY_ON_RANGE_LIST_PARTITION |
| AddPartitionSubPartition | `1513` | ER_ADD_PARTITION_SUBPART_ERROR |
| AddPartitionNoNewPartition | `1514` | ER_ADD_PARTITION_NO_NEW_PARTITION |
| CoalescePartitionNoPartition | `1515` | ER_COALESCE_PARTITION_NO_PARTITION |
| ReorganizePartitionNotExist | `1516` | ER_REORG_PARTITION_NOT_EXIST |
| SameNamePartition | `1517` | ER_SAME_NAME_PARTITION |
| NoBinLog | `1518` | ER_NO_BINLOG_ERROR |
| ConsecutiveReorganizePartitions | `1519` | ER_CONSECUTIVE_REORG_PARTITIONS |
| ReorganizeOutsideRange | `1520` | ER_REORG_OUTSIDE_RANGE |
| PartitionFunctionFailure | `1521` | ER_PARTITION_FUNCTION_FAILURE |
| PartitionStateError | `1522` | ER_PART_STATE_ERROR |
| LimitedPartitionRange | `1523` | ER_LIMITED_PART_RANGE |
| PluginIsNotLoaded | `1524` | ER_PLUGIN_IS_NOT_LOADED |
| WrongValue | `1525` | ER_WRONG_VALUE |
| NoPartitionForGivenValue | `1526` | ER_NO_PARTITION_FOR_GIVEN_VALUE |
| FileGroupOptionOnlyOnce | `1527` | ER_FILEGROUP_OPTION_ONLY_ONCE |
| CreateFileGroupFailed | `1528` | ER_CREATE_FILEGROUP_FAILED |
| DropFileGroupFailed | `1529` | ER_DROP_FILEGROUP_FAILED |
| TableSpaceAutoExtend | `1530` | ER_TABLESPACE_AUTO_EXTEND_ERROR |
| WrongSizeNumber | `1531` | ER_WRONG_SIZE_NUMBER |
| SizeOverflow | `1532` | ER_SIZE_OVERFLOW_ERROR |
| AlterFileGroupFailed | `1533` | ER_ALTER_FILEGROUP_FAILED |
| BinLogRowLogginFailed | `1534` | ER_BINLOG_ROW_LOGGING_FAILED |
| BinLogRowWrongTableDefinition | `1535` | ER_BINLOG_ROW_WRONG_TABLE_DEF |
| BinLogRowRBRToSBR | `1536` | ER_BINLOG_ROW_RBR_TO_SBR |
| EventAlreadyExists | `1537` | ER_EVENT_ALREADY_EXISTS |
| EventStoreFailed | `1538` | ER_EVENT_STORE_FAILED |
| EventDoesNotExist | `1539` | ER_EVENT_DOES_NOT_EXIST |
| EventCannotAlter | `1540` | ER_EVENT_CANT_ALTER |
| EventDropFailed | `1541` | ER_EVENT_DROP_FAILED |
| EventIntervalNotPositiveOrTooBig | `1542` | ER_EVENT_INTERVAL_NOT_POSITIVE_OR_TOO_BIG |
| EventEndsBeforeStarts | `1543` | ER_EVENT_ENDS_BEFORE_STARTS |
| EventExecTimeInThePast | `1544` | ER_EVENT_EXEC_TIME_IN_THE_PAST |
| EventOpenTableFailed | `1545` | ER_EVENT_OPEN_TABLE_FAILED |
| EventNeitherMExpresssionNorMAt | `1546` | ER_EVENT_NEITHER_M_EXPR_NOR_M_AT |
| ColumnCountDoesNotMatchCorrupted | `1547` | ER_OBSOLETE_COL_COUNT_DOESNT_MATCH_CORRUPTED |
| CannotLoadFromTable | `1548` | ER_OBSOLETE_CANNOT_LOAD_FROM_TABLE |
| EventCannotDelete | `1549` | ER_EVENT_CANNOT_DELETE |
| EventCompileError | `1550` | ER_EVENT_COMPILE_ERROR |
| EventSameName | `1551` | ER_EVENT_SAME_NAME |
| EventDataTooLong | `1552` | ER_EVENT_DATA_TOO_LONG |
| DropIndexForeignKey | `1553` | ER_DROP_INDEX_FK |
| WarningDeprecatedSyntaxWithVersion | `1554` | ER_WARN_DEPRECATED_SYNTAX_WITH_VER |
| CannotWriteLockLogTable | `1555` | ER_CANT_WRITE_LOCK_LOG_TABLE |
| CannotLockLogTable | `1556` | ER_CANT_LOCK_LOG_TABLE |
| ForeignDuplicateKey | `1557` | ER_FOREIGN_DUPLICATE_KEY_OLD_UNUSED |
| ColumnCountDoesNotMatchPleaseUpdate | `1558` | ER_COL_COUNT_DOESNT_MATCH_PLEASE_UPDATE |
| TemoraryTablePreventSwitchOutOfRBR | `1559` | ER_TEMP_TABLE_PREVENTS_SWITCH_OUT_OF_RBR |
| StoredFunctionPreventsSwitchBinLogFormat | `1560` | ER_STORED_FUNCTION_PREVENTS_SWITCH_BINLOG_FORMAT |
| NDBCannotSwitchBinLogFormat | `1561` | ER_NDB_CANT_SWITCH_BINLOG_FORMAT |
| PartitionNoTemporary | `1562` | ER_PARTITION_NO_TEMPORARY |
| PartitionConstantDomain | `1563` | ER_PARTITION_CONST_DOMAIN_ERROR |
| PartitionFunctionIsNotAllowed | `1564` | ER_PARTITION_FUNCTION_IS_NOT_ALLOWED |
| DDLLogError | `1565` | ER_DDL_LOG_ERROR |
| NullInValuesLessThan | `1566` | ER_NULL_IN_VALUES_LESS_THAN |
| WrongPartitionName | `1567` | ER_WRONG_PARTITION_NAME |
| CannotChangeTransactionIsolation | `1568` | ER_CANT_CHANGE_TX_CHARACTERISTICS |
| DuplicateEntryAutoIncrementCase | `1569` | ER_DUP_ENTRY_AUTOINCREMENT_CASE |
| EventModifyQueueError | `1570` | ER_EVENT_MODIFY_QUEUE_ERROR |
| EventSetVariableError | `1571` | ER_EVENT_SET_VAR_ERROR |
| PartitionMergeError | `1572` | ER_PARTITION_MERGE_ERROR |
| CannotActivateLog | `1573` | ER_CANT_ACTIVATE_LOG |
| RBRNotAvailable | `1574` | ER_RBR_NOT_AVAILABLE |
| Base64DecodeError | `1575` | ER_BASE64_DECODE_ERROR |
| EventRecursionForbidden | `1576` | ER_EVENT_RECURSION_FORBIDDEN |
| EventsDatabaseError | `1577` | ER_EVENTS_DB_ERROR |
| OnlyIntegersAllowed | `1578` | ER_ONLY_INTEGERS_ALLOWED |
| UnsupportedLogEngine | `1579` | ER_UNSUPORTED_LOG_ENGINE |
| BadLogStatement | `1580` | ER_BAD_LOG_STATEMENT |
| CannotRenameLogTable | `1581` | ER_CANT_RENAME_LOG_TABLE |
| WrongParameterCountToNativeFCT | `1582` | ER_WRONG_PARAMCOUNT_TO_NATIVE_FCT |
| WrongParametersToNativeFCT | `1583` | ER_WRONG_PARAMETERS_TO_NATIVE_FCT |
| WrongParametersToStoredFCT | `1584` | ER_WRONG_PARAMETERS_TO_STORED_FCT |
| NativeFCTNameCollision | `1585` | ER_NATIVE_FCT_NAME_COLLISION |
| DuplicateEntryWithKeyName | `1586` | ER_DUP_ENTRY_WITH_KEY_NAME |
| BinLogPurgeEMFile | `1587` | ER_BINLOG_PURGE_EMFILE |
| EventCannotCreateInThePast | `1588` | ER_EVENT_CANNOT_CREATE_IN_THE_PAST |
| EventCannotAlterInThePast | `1589` | ER_EVENT_CANNOT_ALTER_IN_THE_PAST |
| SlaveIncident | `1590` | ER_SLAVE_INCIDENT |
| NoPartitionForGivenValueSilent | `1591` | ER_NO_PARTITION_FOR_GIVEN_VALUE_SILENT |
| BinLogUnsafeStatement | `1592` | ER_BINLOG_UNSAFE_STATEMENT |
| SlaveFatalError | `1593` | ER_SLAVE_FATAL_ERROR |
| SlaveRelayLogReadFailure | `1594` | ER_SLAVE_RELAY_LOG_READ_FAILURE |
| SlaveRelayLogWriteFailure | `1595` | ER_SLAVE_RELAY_LOG_WRITE_FAILURE |
| SlaveCreateEventFailure | `1596` | ER_SLAVE_CREATE_EVENT_FAILURE |
| SlaveMasterComFailure | `1597` | ER_SLAVE_MASTER_COM_FAILURE |
| BinLogLoggingImpossible | `1598` | ER_BINLOG_LOGGING_IMPOSSIBLE |
| ViewNoCreationContext | `1599` | ER_VIEW_NO_CREATION_CTX |
| ViewInvalidCreationContext | `1600` | ER_VIEW_INVALID_CREATION_CTX |
| StoredRoutineInvalidCreateionContext | `1601` | ER_SR_INVALID_CREATION_CTX |
| TiggerCorruptedFile | `1602` | ER_TRG_CORRUPTED_FILE |
| TriggerNoCreationContext | `1603` | ER_TRG_NO_CREATION_CTX |
| TriggerInvalidCreationContext | `1604` | ER_TRG_INVALID_CREATION_CTX |
| EventInvalidCreationContext | `1605` | ER_EVENT_INVALID_CREATION_CTX |
| TriggerCannotOpenTable | `1606` | ER_TRG_CANT_OPEN_TABLE |
| CannoCreateSubRoutine | `1607` | ER_CANT_CREATE_SROUTINE |
| SlaveAmbiguousExecMode | `1608` | ER_NEVER_USED |
| NoFormatDescriptionEventBeforeBinLogStatement | `1609` | ER_NO_FORMAT_DESCRIPTION_EVENT_BEFORE_BINLOG_STATEMENT |
| SlaveCorruptEvent | `1610` | ER_SLAVE_CORRUPT_EVENT |
| LoadDataInvalidColumn | `1611` | ER_LOAD_DATA_INVALID_COLUMN |
| LogPurgeNoFile | `1612` | ER_LOG_PURGE_NO_FILE |
| XARBTimeout | `1613` | ER_XA_RBTIMEOUT |
| XARBDeadlock | `1614` | ER_XA_RBDEADLOCK |
| NeedRePrepare | `1615` | ER_NEED_REPREPARE |
| DelayedNotSupported | `1616` | ER_DELAYED_NOT_SUPPORTED |
| WarningNoMasterInfo | `1617` | WARN_NO_MASTER_INFO |
| WarningOptionIgnored | `1618` | WARN_OPTION_IGNORED |
| WarningPluginDeleteBuiltIn | `1619` | WARN_PLUGIN_DELETE_BUILTIN |
| WarningPluginBusy | `1620` | WARN_PLUGIN_BUSY |
| VariableIsReadonly | `1621` | ER_VARIABLE_IS_READONLY |
| WarningEngineTransactionRollback | `1622` | ER_WARN_ENGINE_TRANSACTION_ROLLBACK |
| SlaveHeartbeatFailure | `1623` | ER_SLAVE_HEARTBEAT_FAILURE |
| SlaveHeartbeatValueOutOfRange | `1624` | ER_SLAVE_HEARTBEAT_VALUE_OUT_OF_RANGE |
| NDBReplicationSchemaError | `1625` | ER_NDB_REPLICATION_SCHEMA_ERROR |
| ConflictFunctionParseError | `1626` | ER_CONFLICT_FN_PARSE_ERROR |
| ExcepionsWriteError | `1627` | ER_EXCEPTIONS_WRITE_ERROR |
| TooLongTableComment | `1628` | ER_TOO_LONG_TABLE_COMMENT |
| TooLongFieldComment | `1629` | ER_TOO_LONG_FIELD_COMMENT |
| FunctionInExistentNameCollision | `1630` | ER_FUNC_INEXISTENT_NAME_COLLISION |
| DatabaseNameError | `1631` | ER_DATABASE_NAME |
| TableNameErrror | `1632` | ER_TABLE_NAME |
| PartitionNameError | `1633` | ER_PARTITION_NAME |
| SubPartitionNameError | `1634` | ER_SUBPARTITION_NAME |
| TemporaryNameError | `1635` | ER_TEMPORARY_NAME |
| RenamedNameError | `1636` | ER_RENAMED_NAME |
| TooManyConcurrentTransactions | `1637` | ER_TOO_MANY_CONCURRENT_TRXS |
| WarningNonASCIISeparatorNotImplemented | `1638` | WARN_NON_ASCII_SEPARATOR_NOT_IMPLEMENTED |
| DebugSyncTimeout | `1639` | ER_DEBUG_SYNC_TIMEOUT |
| DebugSyncHitLimit | `1640` | ER_DEBUG_SYNC_HIT_LIMIT |
| CannotExecuteInReadOnlyTransaction | `1792` | ER_CANT_EXECUTE_IN_READ_ONLY_TRANSACTION |

## See Also

* namespace [MySqlConnector](../../MySqlConnectorNamespace/)
* assembly [MySqlConnector](../../MySqlConnectorAssembly/)

<!-- DO NOT EDIT: generated by xmldocmd for MySqlConnector.dll -->
